aboutsummaryrefslogtreecommitdiff
path: root/lib/AST/Type.cpp
diff options
context:
space:
mode:
authorDouglas Gregor <dgregor@apple.com>2011-07-11 22:38:07 +0000
committerDouglas Gregor <dgregor@apple.com>2011-07-11 22:38:07 +0000
commit5e78cd43a033b3dedf741fca4fa1652f9cb3e41c (patch)
tree00fc7c665562e62d63149fb5556288313c96e339 /lib/AST/Type.cpp
parentffc97ee1d3d5f7d30ed38fd12995e6db010f7dd0 (diff)
Allow us to compute linkage et al for instantiation-dependent types.
git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@134932 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/AST/Type.cpp')
-rw-r--r--lib/AST/Type.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/AST/Type.cpp b/lib/AST/Type.cpp
index ca63ec87b1..20a0d595e4 100644
--- a/lib/AST/Type.cpp
+++ b/lib/AST/Type.cpp
@@ -1980,8 +1980,8 @@ static CachedProperties computeCachedProperties(const Type *T) {
#define DEPENDENT_TYPE(Class,Base) case Type::Class:
#define NON_CANONICAL_UNLESS_DEPENDENT_TYPE(Class,Base) case Type::Class:
#include "clang/AST/TypeNodes.def"
- // Treat dependent types as external.
- assert(T->isDependentType());
+ // Treat instantiation-dependent types as external.
+ assert(T->isInstantiationDependentType());
return CachedProperties(ExternalLinkage, DefaultVisibility, false);
case Type::Builtin: